==> kt_dart-0.8.0-dev.1.tar.gz: test/kt_dart_test.dart <==
import "collection/collection_mutable_test.dart" as collection_mutable_test;
import "collection/collection_test.dart" as collection_test;
import "collection/collections_test.dart" as collections_test;
import "collection/comparisons_test.dart" as comparisons_test;
import "collection/dart_unmodifiable_set_view_test.dart"
    as dart_unmodifiable_set_view_test;
import "collection/interopt_test.dart" as interopt_test;
import "collection/iterable_extensions_test.dart" as iterable_extensions_test;
import "collection/iterable_mutable_extensions_test.dart"
    as iterable_mutable_extensions_test;
import "collection/iterator_test.dart" as iterator_test;
import "collection/list_empty_test.dart" as list_empty_test;
import "collection/list_extensions_test.dart" as list_extensions_test;
import "collection/list_mutable_extensions_test.dart"
    as list_mutable_extensions_test;
import "collection/list_mutable_test.dart" as list_mutable_test;
import "collection/list_test.dart" as list_test;
import "collection/map_empty_test.dart" as map_empty_test;
import "collection/map_extensions_test.dart" as map_extensions_test;
import "collection/map_mutable_extensions_test.dart"
    as map_mutable_extensions_test;
import "collection/map_mutable_test.dart" as map_mutable_test;
import "collection/map_test.dart" as map_test;
import "collection/set_empty_test.dart" as set_empty_test;
import "collection/set_extensions_test.dart" as set_extensions_test;
import "collection/set_mutable_extensions_test.dart"
    as set_mutable_extensions_test;
import "collection/set_mutable_test.dart" as set_mutable_test;
import "collection/set_test.dart" as set_test;
import "collection/tuples_test.dart" as tuples_test;
import "exception/exceptions_test.dart" as exceptions_test;
import "issues/all_issues.dart" as all_issues;
import "standard/standard_test.dart" as standard_test;
import "util/annotation_test.dart" as annotation_test;
import "util/hash_test.dart" as hash_test;

void main() {
  collection_mutable_test.main();
  collection_test.main();
  collections_test.main();
  comparisons_test.main();
  dart_unmodifiable_set_view_test.main();
  interopt_test.main();
  iterable_extensions_test.main();
  iterable_mutable_extensions_test.main();
  iterator_test.main();
  list_empty_test.main();
  list_extensions_test.main();
  list_mutable_extensions_test.main();
  list_mutable_test.main();
  list_test.main();
  map_empty_test.main();
  map_extensions_test.main();
  map_mutable_extensions_test.main();
  map_mutable_test.main();
  map_test.main();
  set_empty_test.main();
  set_extensions_test.main();
  set_mutable_extensions_test.main();
  set_mutable_test.main();
  set_test.main();
  tuples_test.main();
  exceptions_test.main();
  all_issues.main();
  standard_test.main();
  annotation_test.main();
  hash_test.main();
}

==> kt_dart-0.10.0.tar.gz: test/kt_dart_test.dart <==
import "collection/collection_mutable_test.dart" as collection_mutable_test;
import "collection/collection_test.dart" as collection_test;
import "collection/collections_test.dart" as collections_test;
import "collection/comparisons_test.dart" as comparisons_test;
import "collection/dart_unmodifiable_set_view_test.dart"
    as dart_unmodifiable_set_view_test;
import "collection/interopt_test.dart" as interopt_test;
import "collection/iterable_extensions_test.dart" as iterable_extensions_test;
import "collection/iterable_mutable_extensions_test.dart"
    as iterable_mutable_extensions_test;
import "collection/iterator_test.dart" as iterator_test;
import "collection/list_empty_test.dart" as list_empty_test;
import "collection/list_extensions_test.dart" as list_extensions_test;
import "collection/list_mutable_extensions_test.dart"
    as list_mutable_extensions_test;
import "collection/list_mutable_test.dart" as list_mutable_test;
import "collection/list_test.dart" as list_test;
import "collection/map_empty_test.dart" as map_empty_test;
import "collection/map_extensions_test.dart" as map_extensions_test;
import "collection/map_mutable_extensions_test.dart"
    as map_mutable_extensions_test;
import "collection/map_mutable_test.dart" as map_mutable_test;
import "collection/map_test.dart" as map_test;
import "collection/set_empty_test.dart" as set_empty_test;
import "collection/set_extensions_test.dart" as set_extensions_test;
import "collection/set_mutable_extensions_test.dart"
    as set_mutable_extensions_test;
import "collection/set_mutable_test.dart" as set_mutable_test;
import "collection/set_test.dart" as set_test;
import "collection/tuples_test.dart" as tuples_test;
import "exception/exceptions_test.dart" as exceptions_test;
import "issues/all_issues_test.dart" as all_issues_test;
import "standard/standard_test.dart" as standard_test;
import "util/annotation_test.dart" as annotation_test;
import "util/hash_test.dart" as hash_test;

void main() {
  collection_mutable_test.main();
  collection_test.main();
  collections_test.main();
  comparisons_test.main();
  dart_unmodifiable_set_view_test.main();
  interopt_test.main();
  iterable_extensions_test.main();
  iterable_mutable_extensions_test.main();
  iterator_test.main();
  list_empty_test.main();
  list_extensions_test.main();
  list_mutable_extensions_test.main();
  list_mutable_test.main();
  list_test.main();
  map_empty_test.main();
  map_extensions_test.main();
  map_mutable_extensions_test.main();
  map_mutable_test.main();
  map_test.main();
  set_empty_test.main();
  set_extensions_test.main();
  set_mutable_extensions_test.main();
  set_mutable_test.main();
  set_test.main();
  tuples_test.main();
  exceptions_test.main();
  all_issues_test.main();
  standard_test.main();
  annotation_test.main();
  hash_test.main();
}
